---
authors:
  - Zhiyuan Chen
date: 2024-05-04
---

# heads

--8<-- "multimolecule/module/heads/README.md:8:"

::: multimolecule.module.heads.config

::: multimolecule.module.heads.sequence

::: multimolecule.module.heads.nucleotide

::: multimolecule.module.heads.token

::: multimolecule.module.heads.contact

::: multimolecule.module.heads.pretrain

::: multimolecule.module.heads.generic

::: multimolecule.module.heads.output
